%define urlver %(echo %{version}|cut -d. -f1,2)
# we don't want to provide private python extension libs
%define __noautoprov .*\\.so

%define module Twisted

Summary:	Event-based framework for internet applications
Name:		python-twisted
Version:	17.9.0
Release:	2
License:	MIT
Group:		Development/Python
Url:		http://www.twistedmatrix.com/
Source0:	https://twistedmatrix.com/Releases/Twisted/%{urlver}/%{module}-%{version}.tar.bz2
# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(libtirpc)
BuildRequires:	pkgconfig(python2)
BuildRequires:	pythonegg(setuptools)
BuildRequires:	pythonegg(zope.interface)

Requires:	python-gobject
Requires:	pythonegg(pycrypto)
Requires:	pythonegg(pyopenssl)
Requires:	pythonegg(zope.interface)
# python-twisted-core
Requires:	pythonegg(pyserial)
# python-twisted-conch
Requires:	pythonegg(pyasn1)
Suggests:	python-service_identity

# Bring all provided resources back into the main package namespace.
Obsoletes:	python-twisted-conch < 16
Provides:	python-twisted-conch = %{EVRD}
Obsoletes:	python-twisted-core < 16
Provides:	python-twisted-core = %{EVRD}
Obsoletes:	python-twisted-lore < 16
Provides:	python-twisted-lore = %{EVRD}
Obsoletes:	python-twisted-mail < 16
Provides:	python-twisted-mail = %{EVRD}
Obsoletes:	python-twisted-names < 16
Provides:	python-twisted-names = %{EVRD}
Obsoletes:	python-twisted-news < 16
Provides:	python-twisted-news = %{EVRD}
Obsoletes:	python-twisted-pair < 16
Provides:	python-twisted-pair = %{EVRD}
Obsoletes:	python-twisted-runner < 16
Provides:	python-twisted-runner = %{EVRD}
Obsoletes:	python-twisted-web < 16
Provides:	python-twisted-web = %{EVRD}
Obsoletes:	python-twisted-words < 16
Provides:	python-twisted-words = %{EVRD}

%description
Twisted is a framework, written in Python, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%files
%doc CONTRIBUTING README.rst docs/*
%doc LICENSE
%{_bindir}/cftp
%{_bindir}/ckeygen
%{_bindir}/conch
%{_bindir}/mailmail
%{_bindir}/pyhtmlizer
%{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twist
%{_bindir}/twistd
%{py_platsitedir}/twisted/
%{py_platsitedir}/%{module}-%{version}-py%{py_ver}.egg-info/
%{_mandir}/man1/*.1*

#----------------------------------------------------------------------------

%package -n python3-twisted
Summary:	Python3 event-based framework for internet applications
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3egg(setuptools)
BuildRequires:	python3egg(zope.interface)
Requires:	python-gobject
Requires:	python3egg(pycrypto)
Requires:	python3egg(pyopenssl)
Requires:	python3egg(zope.interface)
# python-twisted-core
Requires:	python3egg(pyserial)
# python-twisted-conch
Requires:	python3egg(pyasn1)

%description -n python3-twisted
Twisted is a framework, written in Python3, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%files -n python3-twisted
%doc CONTRIBUTING README.rst
%doc LICENSE
%{_bindir}/trial3
%{_bindir}/twist3
%{_bindir}/twistd3
%{py3_platsitedir}/twisted/
%{py3_platsitedir}/%{module}-%{version}-py%{py3_ver}.egg-info/

#----------------------------------------------------------------------------

%prep
%setup -qn %{module}-%{version}
%apply_patches
cp -a . %{py3dir}

%build
%py2_build
pushd %{py3dir}
%py3_build
popd

%install
pushd %{py3dir}
%py3_install
# twisted in python 3 supports only few command line tools for now.
# Let's rename the tools the other way round after the python 3 version supports all.
for name in trial twist twistd; do
	mv "%{buildroot}/%{_bindir}/$name"{,3}
done
popd
%py2_install

# no need for c and h source code
find %{buildroot}%{py_platsitedir}/twisted -name '*.c' -delete
find %{buildroot}%{py_platsitedir}/twisted -name '*.h' -delete
find %{buildroot}%{py3_platsitedir}/twisted -name '*.c' -delete
find %{buildroot}%{py3_platsitedir}/twisted -name '*.h' -delete

# pem-certificate
find %{buildroot}%{py_platsitedir}/twisted -name '*.pem' -delete
find %{buildroot}%{py3_platsitedir}/twisted -name '*.pem' -delete

# non-executable-script
chmod +x %{buildroot}%{py_platsitedir}/twisted/mail/test/pop3testserver.py
chmod +x %{buildroot}%{py_platsitedir}/twisted/trial/test/scripttest.py

# no-manual-page-for-binary
mkdir -p %{buildroot}%{_mandir}/man1/
for s in conch core mail; do
	cp -pr docs/$s/man/*.1 %{buildroot}%{_mandir}/man1/
done

%changelog

* Wed Apr 18 2018 Denis Silakov <dsilakov@virtuozzo.com> 17.9.0-2
- (f5301cb) Suggest python-service_identity since it is in main


